<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Notification;
use Teknisa\MAN\Services;
use Zeedhi\Framework\DataSource\Manager;
use Teknisa\MAN\Utilities;

class RestricaoAlimentar extends Crud{
   
    protected $dataSourceName = 'vnd09800_restricaoalimentar';
    protected $service;
    protected $utilService;
    
     public function __construct (Manager $dataSourceManager, Utilities\Util $utilService, Services\RestricaoAlimentar $service){
        $this->service = $service;
        $this->utilService = $utilService;
        parent::__construct($dataSourceManager);
    }
    
    public function save(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $row = $request->getDataSet()->getRows()[0]; 
            $filterData = new \Zeedhi\Framework\DataSource\FilterCriteria('productgroup');
            $filterData->addCondition("CDCONSUMIDOR", \Zeedhi\Framework\DataSource\FilterCriteria::EQ , $row['CDCONSUMIDOR']);
            $filterData->addCondition("CDFAMILISALD", \Zeedhi\Framework\DataSource\FilterCriteria::EQ , $row['CDFAMILISALD']);
            $filterData->addCondition("CDCLIENTE", \Zeedhi\Framework\DataSource\FilterCriteria::EQ , $row['CDCLIENTE']);
            $filterData->addCondition("CDFILIAL", \Zeedhi\Framework\DataSource\FilterCriteria::EQ , $row['CDFILIAL']);
            $filterData->setDataSourceName($this->dataSourceName);
            $dataSet = $this->dataSourceManager->findBy($filterData);
            if(count($dataSet->getRows()) > 0 && $row['__is_new']) {
                throw new \Exception('Essa combinação de códigos já existe no banco de dados');    
            }
            
            $dataSet = $request->getDataSet();
            $dataSet->setDataSourceName($this->dataSourceName);
            $persistedRows = $this->dataSourceManager->persist($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceName, $persistedRows));
            $nrPersistedRows = count($persistedRows);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function delete(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $dataSet = $request->getDataSet();
            $dataSet->setDataSourceName($this->dataSourceName);
            $deletedRows = $this->dataSourceManager->delete($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceName, $deletedRows));
            $nrDeletedRows = count($deletedRows);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function cadAutomaticoCons(DTO\Request\Row $request, DTO\Response $response){
        $conditions = $this->utilService->getParamsAsArray($request);
        $conditions = $this->utilService->buildParams('CDCCUSCLIE',$conditions);
        $conditions = $this->utilService->buildParams('CDTIPOCONS',$conditions);
        $conditions = $this->utilService->buildParams('CDCONSUMIDOR',$conditions);
        try{
            $this->service->cadAutomaticoCons($conditions);
            $response->addDataSet(new DataSet('STATUS', array('status'=>true)));
        }catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function confirmarCadAutProduto(DTO\Request\Row $request, DTO\Response $response){
        $conditions = $this->utilService->getParamsAsArray($request);
        
        try{
            $this->service->confirmarCadAutProduto($conditions);
            $response->addDataSet(new DataSet('STATUS', array('status'=>true)));
        }catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
}